@@ -1,5 +1,7 @@
 function _aws_cdk_aws_logs_destinations_LambdaDestinationOptions(p) {
 }
+function _aws_cdk_aws_logs_destinations_KinesisDestinationProps(p) {
+}
 function _aws_cdk_aws_logs_destinations_KinesisDestination(p) {
 }
 function _aws_cdk_aws_logs_destinations_LambdaDestination(p) {
@@ -19,5 +21,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_logs_destinations_LambdaDestinationOptions, _aws_cdk_aws_logs_destinations_KinesisDestination, _aws_cdk_aws_logs_destinations_LambdaDestination };
+module.exports = { print, _aws_cdk_aws_logs_destinations_LambdaDestinationOptions, _aws_cdk_aws_logs_destinations_KinesisDestinationProps, _aws_cdk_aws_logs_destinations_KinesisDestination, _aws_cdk_aws_logs_destinations_LambdaDestination };
 module.exports.DeprecationError = DeprecationError;
